"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var core_1 = require("@angular/core");
var base64encoder_1 = require("./converter/base64encoder");
var base64decoder_1 = require("./converter/base64decoder");
var uriencoder_1 = require("./converter/uriencoder");
var uridecoder_1 = require("./converter/uridecoder");
var uricomponentencoder_1 = require("./converter/uricomponentencoder");
var uricomponentdecoder_1 = require("./converter/uricomponentdecoder");
var htmlentitiesencoder_1 = require("./converter/htmlentitiesencoder");
var htmlentitiesdecoder_1 = require("./converter/htmlentitiesdecoder");
var dectohexconverter_1 = require("./converter/dectohexconverter");
var hextodecconverter_1 = require("./converter/hextodecconverter");
var dectobinconverter_1 = require("./converter/dectobinconverter");
var bintodecconverter_1 = require("./converter/bintodecconverter");
var quotedprintabledecoder_1 = require("./converter/quotedprintabledecoder");
var quotedprintableencoder_1 = require("./converter/quotedprintableencoder");
var punycodeencoder_1 = require("./converter/punycodeencoder");
var punycodedecoder_1 = require("./converter/punycodedecoder");
var utf8encoder_1 = require("./converter/utf8encoder");
var utf8decoder_1 = require("./converter/utf8decoder");
var ConverterRegistryService = (function () {
    function ConverterRegistryService(wrapper) {
        this.wrapper = wrapper;
        this.converters = [];
        this.init();
    }
    ConverterRegistryService.prototype.getAllConverters = function () {
        return this.converters;
    };
    ConverterRegistryService.prototype.getConverter = function (id) {
        for (var i = 0; i < this.converters.length; i++) {
            if (this.converters[i].getId() == id) {
                return this.converters[i];
            }
        }
        return undefined;
    };
    ConverterRegistryService.prototype.init = function () {
        this.registerConverter(new base64encoder_1.Base64Encoder());
        this.registerConverter(new base64decoder_1.Base64Decoder());
        this.registerConverter(new uriencoder_1.URIEncoder());
        this.registerConverter(new uridecoder_1.URIDecoder());
        this.registerConverter(new uricomponentencoder_1.URIComponentEncoder());
        this.registerConverter(new uricomponentdecoder_1.URIComponentDecoder());
        this.registerConverter(new htmlentitiesencoder_1.HTMLEntitiesEncoder());
        this.registerConverter(new htmlentitiesdecoder_1.HTMLEntitiesDecoder());
        this.registerConverter(new quotedprintableencoder_1.QuotedPrintableEncoder(this.wrapper));
        this.registerConverter(new quotedprintabledecoder_1.QuotedPrintableDecoder(this.wrapper));
        this.registerConverter(new dectohexconverter_1.DecToHexConverter());
        this.registerConverter(new hextodecconverter_1.HexToDecConverter());
        this.registerConverter(new dectobinconverter_1.DecToBinConverter());
        this.registerConverter(new bintodecconverter_1.BinToDecConverter());
        this.registerConverter(new punycodeencoder_1.PunycodeEncoder(this.wrapper));
        this.registerConverter(new punycodedecoder_1.PunycodeDecoder(this.wrapper));
        this.registerConverter(new utf8encoder_1.UTF8Encoder(this.wrapper));
        this.registerConverter(new utf8decoder_1.UTF8Decoder(this.wrapper));
    };
    ConverterRegistryService.prototype.registerConverter = function (converter) {
        this.converters.forEach(function (c) {
            if (c.getId() == converter.getId()) {
                throw new Error("Converter-ID " + converter.getId() + " is already registered!");
            }
        });
        this.converters.push(converter);
    };
    ConverterRegistryService = __decorate([
        core_1.Injectable()
    ], ConverterRegistryService);
    return ConverterRegistryService;
}());
exports.ConverterRegistryService = ConverterRegistryService;
